@@ -27,7 +27,11 @@ func RequireSend[T any](t require.TestingT, ch chan<- T, v T, timeout time.Durat
 
 // RequireReceive waits until res is received from ch or until the timeout is
 // exceeded.  If the timeout is exceeded, the test is failed.
-func RequireReceive[T any](t require.TestingT, ch <-chan T, timeout time.Duration) (res T, ok bool) {
+func RequireReceive[T any](
+	t require.TestingT,
+	ch <-chan T,
+	timeout time.Duration,
+) (res T, ok bool) {
 	if h, isHelper := t.(interface{ Helper() }); isHelper {
 		h.Helper()
 	}
@@ -41,7 +45,6 @@ func RequireReceive[T any](t require.TestingT, ch <-chan T, timeout time.Duratio
 	case <-timer.C:
 		t.Errorf("did not receive after %s", timeout)
 		t.FailNow()
-
 	}
 
 	// Generally unreachable.
